@@ -17,6 +17,7 @@ import urllib.request
 
 from halo import Halo
 from .tools.kataract import generate_scp_tasks, exec_kataract_tasks
+from .default_role import DefaultRole
 
 
 ##
@@ -60,9 +61,11 @@ def get_deployment_file(ctx, deployment_file):
             sys.exit(1)
 
     if not deployment_file:
-        deployment_file = max(
-            glob.glob(f"{op.join(ctx.envdir, 'deploy')}/*"), key=op.getctime
-        )
+        deploy_dir = op.join(ctx.envdir, "deploy")
+        if not op.isdir(deploy_dir):
+            ctx.elog("Failed to find deploy directory, is composition started ?")
+            sys.exit(1)
+        deployment_file = max(glob.glob(f"{deploy_dir}/*::*"), key=op.getctime)
         exit_is_not_file(deployment_file)
         return deployment_file
     else:
@@ -194,15 +197,34 @@ def populate_deployment_vm_by_ip(nodes_info, roles_quantities):
     return deployment, ips
 
 
-def health_check_roles_quantities(nodes_info, roles_quantities_in, ips=None):
+def health_check_roles_quantities(ctx, nodes_info, roles_quantities_in, ips=None):
     roles_quantities = {}
     remaining_role = None
-    nb_remaining = 0
 
     if len(roles_quantities_in) == 0:
         # If no info we take one node per role
         roles_quantities = {role: [role] for role in nodes_info.keys()}
+        if ips:
+            nb_nodes = len(ips) - len(nodes_info.keys())
+            if nb_nodes >= 0 and "node" in roles_quantities:
+                ctx.vlog("Apply node role as default on ")
+                roles_quantities["node"] = [
+                    f"node{i}" for i in range(1, (nb_nodes + 2))
+                ]
     else:
+        sum_nb_asked_machines = 0
+        for role in roles_quantities_in:
+            if type(roles_quantities_in[role]) == int:
+                sum_nb_asked_machines += roles_quantities_in[role]
+            elif type(roles_quantities_in[role]) == list:
+                sum_nb_asked_machines += len(roles_quantities_in[role])
+            else:
+                pass
+        if ips is not None:
+            remaining_available_machines = len(ips) - sum_nb_asked_machines
+        else:
+            remaining_available_machines = -1
+
         # Step 1: if the user only gave the number of nodes of the roles
         for role in roles_quantities_in:
             if type(roles_quantities_in[role]) == int:
@@ -213,6 +235,22 @@ def health_check_roles_quantities(nodes_info, roles_quantities_in, ips=None):
                     roles_quantities[role] = [
                         f"{role}{i}" for i in range(1, nb_nodes + 1)
                     ]
+            elif type(roles_quantities_in[role]) == DefaultRole:
+                nb_min_nodes = roles_quantities_in[role].nb_min_nodes
+                if ips is None:
+                    # in the case of VMs we are not limited
+                    # so we take the min nb of nodes
+                    remaining_available_machines = nb_min_nodes
+                if remaining_available_machines < nb_min_nodes:
+                    raise Exception(
+                        f"Not enough nodes to satisfy default role {role} ({remaining_available_machines} available for {nb_min_nodes} asked)"
+                    )
+                if remaining_available_machines == 1:
+                    roles_quantities[role] = [f"{role}"]
+                else:
+                    roles_quantities[role] = [
+                        f"{role}{i}" for i in range(1, remaining_available_machines + 1)
+                    ]
             else:
                 if not ips:
                     raise Exception(
@@ -227,24 +265,22 @@ def health_check_roles_quantities(nodes_info, roles_quantities_in, ips=None):
 
         # Step 2: add remainings and check that we do not have any conflict on the hostnames
         all_hostnames = list(itertools.chain.from_iterable(roles_quantities.values()))
-        if remaining_role:
-            nb_remaining = len(ips) - len(all_hostnames)
-            if nb_remaining <= 0:
-                raise Exception(f"Nodes remaining is <= 0: {nb_remaining}")
-            roles_quantities[remaining_role] = [
-                f"{remaining_role}{i}" for i in range(1, nb_remaining + 1)
-            ]
         set_hostnames = set(all_hostnames)
         if len(all_hostnames) != len(set_hostnames):
             raise Exception("Conflict in the naming of the node")
     return roles_quantities
 
 
-def populate_deployment_ips(nodes_info, ips, roles_quantities):
-    roles_quantities = health_check_roles_quantities(nodes_info, roles_quantities, ips)
+def populate_deployment_ips(ctx, nodes_info, ips, roles_quantities):
+    roles_quantities = health_check_roles_quantities(
+        ctx, nodes_info, roles_quantities, ips
+    )
     i = 0
     deployment = {}
     for role, v in nodes_info.items():
+        if role not in roles_quantities:
+            ctx.elog(f"role: {role} not found in roles-quantities file")
+            exit(1)
         for hostname in roles_quantities[role]:
             ip = ips[i]
             deployment[ip] = {"role": role, "host": hostname, "init": v["init"]}
@@ -286,10 +322,9 @@ def generate_deployment_info(ctx, ssh_pub_key_file=None):
 
     # if ctx.multiple_compositions:  :: TO REMOVE ???
     #    nodes = ctx.compose_info["nodes"]
-
     if ctx.ip_addresses:
         deployment = populate_deployment_ips(
-            ctx.compose_info["nodes"], ctx.ip_addresses, ctx.roles_quantities
+            ctx, ctx.compose_info["nodes"], ctx.ip_addresses, ctx.roles_quantities
         )
     elif ctx.forward_ssh_port:
         deployment = populate_deployment_forward_ssh_port(ctx.compose_info["nodes"])
@@ -798,7 +833,7 @@ def get_nix_command(ctx):
         local_bin_nix = "{os.environ['HOME']}/.local/bin/nix"
         if not op.exists(local_bin_nix):
             ctx.elog(
-                "Nix not found, it can by installed in $HOME/.local/bin with command: nxc init --install-nix"
+                "Nix not found, it can by installed in $HOME/.local/bin with command: nxc helper install-nix"
             )
             sys.exit(1)
         else:
