@@ -1,18 +1,22 @@
 import click
 from ..context import pass_context
 from ..g5k import key_sleep_script
+from ..actions import install_nix_static
 
 
 def print_helper(ctx, options):
     for option in options:
-        if option == "g5k_script":
+        if (option == "g5k_script") or (option == "g5k-script"):
             click.echo(key_sleep_script)
+        elif option == "install-nix":
+            install_nix_static()
         else:
             ctx.elog(f"Helper: {option} does not exist")
 
 
 def print_helper_list(helper_options):
-    print("g5k_script: print path to g5k_key_sleep_script Grid'5000 script")
+    print("g5k-script: print path to g5k_key_sleep_script Grid'5000 script")
+    print("install-nix: install the nix command in ~/.local/bin")
 
 
 @click.command("helper")
